@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Jul 2003
 ;;;;
-;;;; $Id: os.lisp 10042 2004-09-28 06:20:21Z kevin $
+;;;; $Id: os.lisp 10227 2004-12-27 03:46:01Z kevin $
 ;;;;
 ;;;; *************************************************************************
 
@@ -159,3 +159,21 @@ returns (VALUES output-string pid)"
     #-allegro
     (with-open-file (in file :direction :input)
       (file-length in))))
+
+(defun getpid ()
+  "Return the PID of the lisp process."
+  #+allegro (excl::getpid)
+  #+(and lispworks win32) (win32:get-current-process-id)
+  #+(and lispworks (not win32)) (system::getpid)
+  #+sbcl (sb-posix:getpid)
+  #+cmu (unix:unix-getpid)
+  #+openmcl (ccl:getpid)
+  #+(and clisp unix) (system::program-id)
+  #+(and clisp win32) (cond ((find-package :win32)
+			     (funcall (find-symbol "GetCurrentProcessId" 
+						   :win32)))
+			    (t
+			     (system::getenv "PID")))
+  )
+
+
